{-# LANGUAGE OverloadedStrings #-}
-- | Build time configuration used during code generation.
module GI.DbusmenuGtk3.Config ( overrides, modules ) where

import qualified Data.Text as T
import Data.Text (Text)

-- | Overrides used when generating these bindings.
overrides :: Text
overrides = T.unlines
 [ "set-attr Dbusmenu/MenuitemClass/buildvariant/@type name zzz"]

-- | Modules in this package
modules :: [Text]
modules =  [ "GI.DbusmenuGtk3.Config"
 , "GI.DbusmenuGtk3"
 , "GI.DbusmenuGtk3.Constants"
 , "GI.DbusmenuGtk3.Functions"
 , "GI.DbusmenuGtk3.Objects"
 , "GI.DbusmenuGtk3.Objects.Client"
 , "GI.DbusmenuGtk3.Objects.Menu"]
